import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * Use this data source to get information about all Wavefront alerts.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as wavefront from "@pulumi/wavefront";
 *
 * // Get the information about all alerts.
 * const example = wavefront.getAlerts({
 *     limit: 10,
 *     offset: 0,
 * });
 * ```
 */
export declare function getAlerts(args?: GetAlertsArgs, opts?: pulumi.InvokeOptions): Promise<GetAlertsResult>;
/**
 * A collection of arguments for invoking getAlerts.
 */
export interface GetAlertsArgs {
    /**
     * Limit is the maximum number of results to be returned. Defaults to 100.
     */
    limit?: number;
    /**
     * Offset is the offset from the first result to be returned. Defaults to 0.
     */
    offset?: number;
}
/**
 * A collection of values returned by getAlerts.
 */
export interface GetAlertsResult {
    /**
     * List of all alerts in Wavefront. For each alert you will see a list of attributes.
     */
    readonly alerts: outputs.GetAlertsAlert[];
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    readonly limit?: number;
    readonly offset?: number;
}
/**
 * Use this data source to get information about all Wavefront alerts.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as wavefront from "@pulumi/wavefront";
 *
 * // Get the information about all alerts.
 * const example = wavefront.getAlerts({
 *     limit: 10,
 *     offset: 0,
 * });
 * ```
 */
export declare function getAlertsOutput(args?: GetAlertsOutputArgs, opts?: pulumi.InvokeOptions): pulumi.Output<GetAlertsResult>;
/**
 * A collection of arguments for invoking getAlerts.
 */
export interface GetAlertsOutputArgs {
    /**
     * Limit is the maximum number of results to be returned. Defaults to 100.
     */
    limit?: pulumi.Input<number>;
    /**
     * Offset is the offset from the first result to be returned. Defaults to 0.
     */
    offset?: pulumi.Input<number>;
}
